===========
Change logs
===========

v0.1.3
======

:Date: 2025-05-11 (Asia/Tokyo)

Fixes
-----

* fix that syntax highlighting is broken in code-block
  by `peacock0803sz <https://github.com/peacock0803sz>`_
  on `#3 <https://github.com/atsphinx/linebreak/pull/3>`_.

v0.1.2
======

:Date: 2024-11-04 (JST)

Fixes
-----

* Remove duplicated linebreak nodes.

v0.1.1
======

:Date: 2024-11-04 (JST)

Fixes
-----

* Work for doctree parsed from MyST.

v0.1.0
======

:Date: 2024-10-31 (JST)

Features
--------

* Implement feature as very simple approach.
* There are not configurations.
